'use strict';

/* For ESLint: List any global identifiers used in this file below */
/* global settingsObj, chrome, logging, LocalCDN */

// OPTIONAL SETTINGS
function Settings() {
  this.settingsKey = 'settings';
  this.defaults = {
    debug_logging: false,
    display_stats: true,
  };
  const localThis = this;
  this.initialize = new Promise(((resolve) => {
    chrome.storage.local.get(localThis.settingsKey, (response) => {
      const settings = response.settings || {};
      localThis.data = $.extend(localThis.defaults, settings);
      if (settings.debug_logging) {
        logging(true);
      }
      resolve();
    });
  }));
}

Settings.prototype = {
  set(name, isEnabled, callback) {
    this.data[name] = isEnabled;
    const localThis = this;
    const localName = name;
    const localIsEnabled = isEnabled;

    // Don't store defaults that the user hasn't modified
    chrome.storage.local.get(this.settingsKey, (response) => {
      // Don't store defaults that the user hasn't modified
      const storedData = response[localThis.settingsKey] || {};
      storedData[localName] = localIsEnabled;
      chrome.storage.local.set({ settings: storedData });
      if (callback !== undefined && typeof callback === 'function') {
        callback();
      }
    });
  },

  getAll() {
    return this.data;
  },

  onload() {
    return this.initialize;
  },

};

const getSettings = function () {
  return settingsObj.getAll();
};

const setSetting = function (name, isEnabled, callback) {
  settingsObj.set(name, isEnabled, callback);

  if (name === 'debug_logging') {
    logging(isEnabled);
  }
};

const disableSetting = function (name) {
  settingsObj.set(name, false);
};

// Attach methods to window
Object.assign(window, {
  disableSetting,
  getSettings,
  setSetting,
});
